summaryrefslogtreecommitdiffstats
path: root/src/schedule.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/schedule.h')
-rw-r--r--src/schedule.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/schedule.h b/src/schedule.h
index adc99eb..d3725fd 100644
--- a/src/schedule.h
+++ b/src/schedule.h
@@ -26,7 +26,7 @@
class KPrinter;
-class KToggleAction;
+class TDEToggleAction;
class KURL;
class TQLineEdit;
class TQComboBox;
@@ -37,8 +37,8 @@ class KTView;
class TQListViewItem;
class TQPushButton;
class TQLabel;
-class KProcess;
-class KConfig;
+class TDEProcess;
+class TDEConfig;
class KURLRequester;
class CollectionSetup;
class TQToolButton;
@@ -105,14 +105,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- //void saveProperties(KConfig *);
+ //void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- //void readProperties(KConfig *);
+ //void readProperties(TDEConfig *);
private slots:
@@ -141,9 +141,9 @@ private:
// TQListView *resultview;
TQPushButton *search_button, *cancel_button;
TQLabel *status_label, *status2_label,*matches_label,*matches2_label;
- KProcess *childproc;
+ TDEProcess *childproc;
TQString buf;
- KConfig* config;
+ TDEConfig* config;
bool errorsEncountered;
TQPushButton* adv_options;
TQString urlsToScan;
@@ -105,14 +105,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties